;;; phil-macros.el -- Phil's Macros
;;; Commentary:
;;; Code:

(require 'gin-mode)

;; Pour les quotes de mail trop longues (via insert-kbd-macro)
(defun mailcut ()
  "Format lines from quoted mails."
  (interactive)
  (end-of-line)
  (kill-line)
  (when (re-search-forward "[ >]*" nil t)
    (replace-match " " nil t))
  (just-one-space)
  (end-of-line)
  (gin-do-auto-fill))

(defvar phil-scissors ">8 --------------------------------------------------------------- 8<"
  "String to insert in \\[scissors].")

(defun scissors()
  "Insert a line of SCISSORS in the buffer."
  (interactive)
  (insert phil-scissors)
  (forward-line 1))

(defun snip-lines-mail ()
  "Delete all lines except the first three in the current buffer selection.
For the first and last remaining lines, remove all characters after the prefix
composed of spaces and '>'.  For the middle line, remove all characters after
the prefix and insert '[snip]' after the remaining prefix."
  (interactive)
  (save-excursion
    (let ((begin (region-beginning))
          (end (region-end)))
      (goto-char end)
      (forward-line -1)
      (setq end (point))
      (goto-char begin)
      (forward-line 2)
      (setq begin (point))
      (delete-region begin end)
      (goto-char begin)
      (forward-line -2)
      (if (re-search-forward "^\\([ >]*\\)\\(.*\\)$" nil t)
          (replace-match "" nil nil nil 2))
      (forward-line 1)
      (if (re-search-forward "^\\([ >]*\\)\\(.*\\)$" nil t)
          (replace-match "[snip]" nil nil nil 2))
      (forward-line 1)
      (if (re-search-forward "^\\([ >]*\\)\\(.*\\)$" nil t)
          (replace-match "" nil nil nil 2))
      (forward-line 1))))

(defun cite-mail-part ()
  "Prefix each line in the region with '> '."
  (interactive)
  (save-excursion
    (let ((begin (region-beginning))
          (end (region-end)))
      (goto-char begin)
      (while (< (point) end)
	(beginning-of-line)
	(insert "> ")
	(forward-line 1)))))

(defun odj-org()
  "Translate a text-based agenda to an org structure."
  (interactive)
  (save-excursion
    (let ((begin (region-beginning))
          (end (region-end)))
      (goto-char begin)
      (while (< (point) end)
	(beginning-of-line)
	(if (re-search-forward "^\\([0-9]+[^ ]?\\) " nil t)
            (replace-match "***" nil nil nil 1))
	(forward-line 1)))))

(provide 'phil-macros)
;;; phil-macros.el ends here
